import requests
from faceitpy.hub import Hub
from faceitpy import errors
import json


class FaceItApi:
    """Represents a connection to the FACEIT Api."""

    def __init__(self, token: str):
        self.__base = "https://open.faceit.com/data/v4"
        self.__token = token
        self.__headers = {
            "accept": "application/json",
            "Authorization": f"Bearer {token}",
        }

    def get_hub(self, hub_id: str) -> Hub:
        """Retrieves the information of the specified hub."""

        # Make the request to the api

        r = requests.get(f"{self.__base}/hubs/{hub_id}", headers=self.__headers)
        rdata = json.loads(r.text)

        if r.status_code == 403:
            raise errors.Forbidden(rdata["errors"][0]["message"])

        # Create a HubData object
        hub = Hub(rdata, self.__token)

        return hub
