import requests
from faceitpy.types.organizer import OrganizerData
import json


class Organizer:
    """Represents a FACEIT Hub organizer."""

    def __init__(self, data: OrganizerData, api_token: str):
        self.__BASE = "https://open.faceit.com/data/v4"
        self.__HEADERS = {
            "accept": "application/json",
            "Authorization": f"Bearer {api_token}",
        }
        self.__token = api_token
        pass

        # Set attributes
        self.id = data.get("organizer_id", None)
        self.avatar = data.get("avatar", None)
        self.cover = data.get("cover", None)
        self.name = data.get("name", None)
        self.description = data.get("description", None)
        self.type = data.get("type", None)
        self.facebook = data.get("facebook", None)
        self.youtube = data.get("youtube", None)
        self.twitter = data.get("twitter", None)
        self.twitch = data.get("twitch", None)
        self.vk = data.get("vk", None)
        self.website = data.get("website", None)
        self.url = data.get("faceit_url", None)
        self.followers = data.get("followers_count", None)

        # Populate other attributes
        # TODO: championships and games
        print(f"Populating hubs for organizer {self.id}")
        self._set_hubs()

    @classmethod
    def _from_organizer_id(cls, id: str, api_token: str):
        r = requests.get(
            f"https://open.faceit.com/data/v4/organizers/{id}",
            headers={
                "accept": "application/json",
                "Authorization": f"Bearer {api_token}",
            },
        )

        response = json.loads(r.text)

        return Organizer(data=response, api_token=api_token)

    def _set_hubs(self):
        """Gets 100 hubs the organizer is part of."""

        from faceitpy.hub import Hub

        r = requests.get(
            f"{self.__BASE}/organizers/{self.id}/hubs", headers=self.__HEADERS
        )
        response = json.loads(r.text)
        print(response)

        self.hubs = []

        for hub in response["items"]:
            self.hubs.append(Hub(hub, self.__token, self))
